changelog — django-cumulus v0.3.1 documentation

### Navigation

- index
- previous |
- django-cumulus v0.3.1 documentation »

# changelog

## Version 0.3, 18 May 2010

- Fixed syncstatic deletion bug
- Require verbosity > 1 for syncstatic output

## Version 0.3, 17 May 2010

- Added syncstatic management command

## Version 0.2.3, 03 May 2010

- Fix bug when accessing imagekit attributes
- Fix setup.py distribute installation issue

## Version 0.2.2, 11 February 2010

- Fixed bug when using django-imagekit

## Version 0.2, 10 February 2010

- Changed focus and aim of project
- Removed all previous custom admin work
- Incorporated CloudFilesStorage custom storage backend
- Added sphinx docs
- Converted setup to use distribute

## Version 0.1, 28 July 2009

- Initial release

### Navigation

- index
- previous |
- django-cumulus v0.3.1 documentation »